from capesbusca.filters.filter import Filter
from capesbusca.filters.ano import Ano
from capesbusca.filters.areaavaliacao import AreaAvaliacao
from capesbusca.filters.areaconcentracao import AreaConcentracao
from capesbusca.filters.areaconhecimento import AreaConhecimento
from capesbusca.filters.autor import Autor
from capesbusca.filters.banca import Banca
from capesbusca.filters.biblioteca import Biblioteca
from capesbusca.filters.grauacademico import GrauAcademico
from capesbusca.filters.instituicao import Instituicao
from capesbusca.filters.orientador import Orientador
from capesbusca.filters.programa import Programa
